@@ -5,15 +5,12 @@ from invenio_records_resources.services.records.schema import (
     BaseRecordSchema as InvenioBaseRecordSchema,
 )
 from invenio_vocabularies.services.schema import i18n_strings
-from marshmallow import ValidationError
 from marshmallow import fields as ma_fields
 from marshmallow import validate as ma_validate
-from marshmallow_utils import fields as mu_fields
-from marshmallow_utils import schemas as mu_schemas
 from marshmallow_utils.fields import edtfdatestring as mu_fields_edtf
 from oarepo_runtime.i18n.schema import I18nSchema
-from oarepo_runtime.ui import marshmallow as l10n
 from oarepo_runtime.validation import validate_date
+from oarepo_vocabularies.services.schemas import HierarchySchema
 
 from nr_metadata.schema.identifiers import (
     NRAuthorityIdentifierSchema,
@@ -34,6 +31,7 @@ class NRAffiliationVocabularySchema(ma.Schema):
 
     _id = ma_fields.String(data_key="id", attribute="id")
     title = i18n_strings
+    hierarchy = ma_fields.Nested(lambda: HierarchySchema())
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -105,6 +103,14 @@ class NRLanguageVocabularySchema(ma.Schema):
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
+class NRLicenseVocabularySchema(ma.Schema):
+    """NRLicenseVocabularySchema schema."""
+
+    _id = ma_fields.String(data_key="id", attribute="id")
+    title = i18n_strings
+    _version = ma_fields.String(data_key="@v", attribute="@v")
+
+
 class NRAccessRightsVocabularySchema(ma.Schema):
     """NRAccessRightsVocabularySchema schema."""
 
@@ -240,7 +246,7 @@ class NRCommonMetadataSchema(ma.Schema):
     abstract = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
     methods = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
     technicalInfo = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
-    rights = ma_fields.List(ma_fields.Nested(lambda: NRAccessRightsVocabularySchema()))
+    rights = ma_fields.List(ma_fields.Nested(lambda: NRLicenseVocabularySchema()))
     accessRights = ma_fields.Nested(lambda: NRAccessRightsVocabularySchema())
     relatedItems = ma_fields.List(ma_fields.Nested(lambda: NRRelatedItemSchema()))
     fundingReferences = ma_fields.List(
